@@ -17,21 +17,22 @@ open Ping_pong.Org_foo_bar
 let ping proxy msg =
   OBus_method.call m_Ping proxy msg
 
-lwt _ =
-  lwt bus = OBus_bus.session () in
+let _ = Lwt_main.run begin
+  let%lwt bus = OBus_bus.session () in
 
   (* Create a proxy for the remote object *)
   let proxy = OBus_proxy.make (OBus_peer.make bus "org.plop") ["plip"] in
 
   (* Send a ping *)
-  lwt () = printl "trying to ping the pong service..." in
+  let%lwt () = printl "trying to ping the pong service..." in
 
-  try_lwt
-    lwt msg = ping proxy "coucou" in
+  try%lwt
+    let%lwt msg = ping proxy "coucou" in
     printlf "received: %s" msg
   with
     | OBus_bus.Name_has_no_owner msg ->
-        lwt () = printl "You must run pong to try this sample!" in
+        let%lwt () = printl "You must run pong to try this sample!" in
         exit 1
     | exn ->
-        raise_lwt exn
+        Lwt.fail exn
+end
